@@ -3,9 +3,9 @@ Main interface for iot1click-devices service type definitions.
 
 Usage::
 
-    from mypy_boto3.iot1click_devices.type_defs import ClaimDevicesByClaimCodeResponseTypeDef
+    from mypy_boto3.iot1click_devices.type_defs import DeviceDescriptionTypeDef
 
-    data: ClaimDevicesByClaimCodeResponseTypeDef = {...}
+    data: DeviceDescriptionTypeDef = {...}
 """
 import sys
 from typing import Any, Dict, List
@@ -17,16 +17,16 @@ else:
 
 
 __all__ = (
-    "ClaimDevicesByClaimCodeResponseTypeDef",
     "DeviceDescriptionTypeDef",
-    "DescribeDeviceResponseTypeDef",
+    "DeviceEventTypeDef",
     "DeviceMethodTypeDef",
+    "DeviceTypeDef",
+    "ClaimDevicesByClaimCodeResponseTypeDef",
+    "DescribeDeviceResponseTypeDef",
     "FinalizeDeviceClaimResponseTypeDef",
     "GetDeviceMethodsResponseTypeDef",
     "InitiateDeviceClaimResponseTypeDef",
     "InvokeDeviceMethodResponseTypeDef",
-    "DeviceTypeDef",
-    "DeviceEventTypeDef",
     "ListDeviceEventsResponseTypeDef",
     "ListDevicesResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
@@ -34,10 +34,6 @@ __all__ = (
     "UnclaimDeviceResponseTypeDef",
 )
 
-ClaimDevicesByClaimCodeResponseTypeDef = TypedDict(
-    "ClaimDevicesByClaimCodeResponseTypeDef", {"ClaimCode": str, "Total": int}, total=False
-)
-
 DeviceDescriptionTypeDef = TypedDict(
     "DeviceDescriptionTypeDef",
     {
@@ -52,20 +48,32 @@ DeviceDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-DescribeDeviceResponseTypeDef = TypedDict(
-    "DescribeDeviceResponseTypeDef", {"DeviceDescription": DeviceDescriptionTypeDef}, total=False
+DeviceEventTypeDef = TypedDict(
+    "DeviceEventTypeDef", {"Device": "DeviceTypeDef", "StdEvent": str}, total=False
 )
 
 DeviceMethodTypeDef = TypedDict(
     "DeviceMethodTypeDef", {"DeviceType": str, "MethodName": str}, total=False
 )
 
+DeviceTypeDef = TypedDict(
+    "DeviceTypeDef", {"Attributes": Dict[str, Any], "DeviceId": str, "Type": str}, total=False
+)
+
+ClaimDevicesByClaimCodeResponseTypeDef = TypedDict(
+    "ClaimDevicesByClaimCodeResponseTypeDef", {"ClaimCode": str, "Total": int}, total=False
+)
+
+DescribeDeviceResponseTypeDef = TypedDict(
+    "DescribeDeviceResponseTypeDef", {"DeviceDescription": "DeviceDescriptionTypeDef"}, total=False
+)
+
 FinalizeDeviceClaimResponseTypeDef = TypedDict(
     "FinalizeDeviceClaimResponseTypeDef", {"State": str}, total=False
 )
 
 GetDeviceMethodsResponseTypeDef = TypedDict(
-    "GetDeviceMethodsResponseTypeDef", {"DeviceMethods": List[DeviceMethodTypeDef]}, total=False
+    "GetDeviceMethodsResponseTypeDef", {"DeviceMethods": List["DeviceMethodTypeDef"]}, total=False
 )
 
 InitiateDeviceClaimResponseTypeDef = TypedDict(
@@ -76,23 +84,15 @@ InvokeDeviceMethodResponseTypeDef = TypedDict(
     "InvokeDeviceMethodResponseTypeDef", {"DeviceMethodResponse": str}, total=False
 )
 
-DeviceTypeDef = TypedDict(
-    "DeviceTypeDef", {"Attributes": Dict[str, Any], "DeviceId": str, "Type": str}, total=False
-)
-
-DeviceEventTypeDef = TypedDict(
-    "DeviceEventTypeDef", {"Device": DeviceTypeDef, "StdEvent": str}, total=False
-)
-
 ListDeviceEventsResponseTypeDef = TypedDict(
     "ListDeviceEventsResponseTypeDef",
-    {"Events": List[DeviceEventTypeDef], "NextToken": str},
+    {"Events": List["DeviceEventTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListDevicesResponseTypeDef = TypedDict(
     "ListDevicesResponseTypeDef",
-    {"Devices": List[DeviceDescriptionTypeDef], "NextToken": str},
+    {"Devices": List["DeviceDescriptionTypeDef"], "NextToken": str},
     total=False,
 )
 
